"use client";

import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import { useLocale } from "next-intl";
import { Locale } from "@/i18n/config";
import { setUserLocale } from "@/services/locale";

const languages = [
  { value: "en-US", label: "English (United States)", flag: "🇺🇸" },
  { value: "zh-CN", label: "简体中文", flag: "🇨🇳" },
];

export default function LanguageSwitcher() {
  const locale = useLocale();

  function onChange(value: string) {
    const locale = value as Locale;
    setUserLocale(locale);
  }

  return (
    <div className="space-y-2">
      <Select defaultValue={locale} onValueChange={onChange}>
        <SelectTrigger className="[&>span]:flex [&>span]:items-center [&>span]:gap-2 [&>span_svg]:shrink-0 [&>span_svg]:text-muted-foreground/80">
          <SelectValue placeholder="Select language" />
        </SelectTrigger>
        <SelectContent className="[&_*[role=option]>span>svg]:shrink-0 [&_*[role=option]>span>svg]:text-muted-foreground/80 [&_*[role=option]>span]:end-2 [&_*[role=option]>span]:start-auto [&_*[role=option]>span]:flex [&_*[role=option]>span]:items-center [&_*[role=option]>span]:gap-2 [&_*[role=option]]:pe-8 [&_*[role=option]]:ps-2">
          {languages.map((item) => (
            <SelectItem key={item.value} value={item.value}>
              <span className="text-lg leading-none">{item.flag}</span>{" "}
              <span className="truncate">{item.label}</span>
            </SelectItem>
          ))}
        </SelectContent>
      </Select>
    </div>
  );
}
